# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .attribute_importer_identity_provider_mapper import *
from .attribute_to_role_identity_mapper import *
from .custom_identity_provider_mapping import *
from .custom_user_federation import *
from .default_groups import *
from .default_roles import *
from .generic_client_protocol_mapper import *
from .generic_client_role_mapper import *
from .get_authentication_execution import *
from .get_authentication_flow import *
from .get_client_description_converter import *
from .get_group import *
from .get_realm import *
from .get_realm_keys import *
from .get_role import *
from .get_user import *
from .get_user_realm_roles import *
from .group import *
from .group_memberships import *
from .group_permissions import *
from .group_roles import *
from .hardcoded_attribute_identity_provider_mapper import *
from .hardcoded_role_identity_mapper import *
from .identity_provider_token_exchange_scope_permission import *
from .provider import *
from .realm import *
from .realm_events import *
from .realm_keystore_aes_generated import *
from .realm_keystore_ecdsa_generated import *
from .realm_keystore_hmac_generated import *
from .realm_keystore_java_generated import *
from .realm_keystore_rsa import *
from .realm_keystore_rsa_generated import *
from .required_action import *
from .role import *
from .user import *
from .user_groups import *
from .user_roles import *
from .user_template_importer_identity_provider_mapper import *
from .users_permissions import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_keycloak.authentication as __authentication
    authentication = __authentication
    import pulumi_keycloak.config as __config
    config = __config
    import pulumi_keycloak.ldap as __ldap
    ldap = __ldap
    import pulumi_keycloak.oidc as __oidc
    oidc = __oidc
    import pulumi_keycloak.openid as __openid
    openid = __openid
    import pulumi_keycloak.saml as __saml
    saml = __saml
else:
    authentication = _utilities.lazy_import('pulumi_keycloak.authentication')
    config = _utilities.lazy_import('pulumi_keycloak.config')
    ldap = _utilities.lazy_import('pulumi_keycloak.ldap')
    oidc = _utilities.lazy_import('pulumi_keycloak.oidc')
    openid = _utilities.lazy_import('pulumi_keycloak.openid')
    saml = _utilities.lazy_import('pulumi_keycloak.saml')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "keycloak",
  "mod": "authentication/execution",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/execution:Execution": "Execution"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/executionConfig",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/executionConfig:ExecutionConfig": "ExecutionConfig"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/flow",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/flow:Flow": "Flow"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "authentication/subflow",
  "fqn": "pulumi_keycloak.authentication",
  "classes": {
   "keycloak:authentication/subflow:Subflow": "Subflow"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/attributeImporterIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/attributeImporterIdentityProviderMapper:AttributeImporterIdentityProviderMapper": "AttributeImporterIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/attributeToRoleIdentityMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/attributeToRoleIdentityMapper:AttributeToRoleIdentityMapper": "AttributeToRoleIdentityMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/customIdentityProviderMapping",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/customIdentityProviderMapping:CustomIdentityProviderMapping": "CustomIdentityProviderMapping"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/customUserFederation",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/customUserFederation:CustomUserFederation": "CustomUserFederation"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/defaultGroups",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/defaultGroups:DefaultGroups": "DefaultGroups"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/defaultRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/defaultRoles:DefaultRoles": "DefaultRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/genericClientProtocolMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/genericClientProtocolMapper:GenericClientProtocolMapper": "GenericClientProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/genericClientRoleMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/genericClientRoleMapper:GenericClientRoleMapper": "GenericClientRoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/group",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/group:Group": "Group"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupMemberships",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupMemberships:GroupMemberships": "GroupMemberships"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupPermissions",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupPermissions:GroupPermissions": "GroupPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/groupRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/groupRoles:GroupRoles": "GroupRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/hardcodedAttributeIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/hardcodedAttributeIdentityProviderMapper:HardcodedAttributeIdentityProviderMapper": "HardcodedAttributeIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/hardcodedRoleIdentityMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/hardcodedRoleIdentityMapper:HardcodedRoleIdentityMapper": "HardcodedRoleIdentityMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/identityProviderTokenExchangeScopePermission",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/identityProviderTokenExchangeScopePermission:IdentityProviderTokenExchangeScopePermission": "IdentityProviderTokenExchangeScopePermission"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realm",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realm:Realm": "Realm"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmEvents",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmEvents:RealmEvents": "RealmEvents"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreAesGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreAesGenerated:RealmKeystoreAesGenerated": "RealmKeystoreAesGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreEcdsaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreEcdsaGenerated:RealmKeystoreEcdsaGenerated": "RealmKeystoreEcdsaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreHmacGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreHmacGenerated:RealmKeystoreHmacGenerated": "RealmKeystoreHmacGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreJavaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreJavaGenerated:RealmKeystoreJavaGenerated": "RealmKeystoreJavaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreRsa",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreRsa:RealmKeystoreRsa": "RealmKeystoreRsa"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/realmKeystoreRsaGenerated",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/realmKeystoreRsaGenerated:RealmKeystoreRsaGenerated": "RealmKeystoreRsaGenerated"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/requiredAction",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/requiredAction:RequiredAction": "RequiredAction"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/role",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/role:Role": "Role"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/user",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/user:User": "User"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userGroups",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userGroups:UserGroups": "UserGroups"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userRoles",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userRoles:UserRoles": "UserRoles"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/userTemplateImporterIdentityProviderMapper",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/userTemplateImporterIdentityProviderMapper:UserTemplateImporterIdentityProviderMapper": "UserTemplateImporterIdentityProviderMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "index/usersPermissions",
  "fqn": "pulumi_keycloak",
  "classes": {
   "keycloak:index/usersPermissions:UsersPermissions": "UsersPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/fullNameMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/fullNameMapper:FullNameMapper": "FullNameMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/groupMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/groupMapper:GroupMapper": "GroupMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/hardcodedGroupMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/hardcodedGroupMapper:HardcodedGroupMapper": "HardcodedGroupMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/hardcodedRoleMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/hardcodedRoleMapper:HardcodedRoleMapper": "HardcodedRoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/msadLdsUserAccountControlMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/msadLdsUserAccountControlMapper:MsadLdsUserAccountControlMapper": "MsadLdsUserAccountControlMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/msadUserAccountControlMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/msadUserAccountControlMapper:MsadUserAccountControlMapper": "MsadUserAccountControlMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/roleMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/roleMapper:RoleMapper": "RoleMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/userAttributeMapper",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/userAttributeMapper:UserAttributeMapper": "UserAttributeMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "ldap/userFederation",
  "fqn": "pulumi_keycloak.ldap",
  "classes": {
   "keycloak:ldap/userFederation:UserFederation": "UserFederation"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "oidc/googleIdentityProvider",
  "fqn": "pulumi_keycloak.oidc",
  "classes": {
   "keycloak:oidc/googleIdentityProvider:GoogleIdentityProvider": "GoogleIdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "oidc/identityProvider",
  "fqn": "pulumi_keycloak.oidc",
  "classes": {
   "keycloak:oidc/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/audienceProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/audienceProtocolMapper:AudienceProtocolMapper": "AudienceProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/audienceResolveProtocolMappter",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/audienceResolveProtocolMappter:AudienceResolveProtocolMappter": "AudienceResolveProtocolMappter"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/client",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/client:Client": "Client"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAggregatePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAggregatePolicy:ClientAggregatePolicy": "ClientAggregatePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationPermission",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationPermission:ClientAuthorizationPermission": "ClientAuthorizationPermission"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationResource",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationResource:ClientAuthorizationResource": "ClientAuthorizationResource"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientAuthorizationScope",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientAuthorizationScope:ClientAuthorizationScope": "ClientAuthorizationScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientDefaultScopes",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientDefaultScopes:ClientDefaultScopes": "ClientDefaultScopes"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientGroupPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientGroupPolicy:ClientGroupPolicy": "ClientGroupPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientJsPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientJsPolicy:ClientJsPolicy": "ClientJsPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientOptionalScopes",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientOptionalScopes:ClientOptionalScopes": "ClientOptionalScopes"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientPermissions",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientPermissions:ClientPermissions": "ClientPermissions"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientPolicy:ClientPolicy": "ClientPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientRolePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientRolePolicy:ClientRolePolicy": "ClientRolePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientScope",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientScope:ClientScope": "ClientScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientServiceAccountRealmRole",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientServiceAccountRealmRole:ClientServiceAccountRealmRole": "ClientServiceAccountRealmRole"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientServiceAccountRole",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientServiceAccountRole:ClientServiceAccountRole": "ClientServiceAccountRole"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientTimePolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientTimePolicy:ClientTimePolicy": "ClientTimePolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/clientUserPolicy",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/clientUserPolicy:ClientUserPolicy": "ClientUserPolicy"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/fullNameProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/fullNameProtocolMapper:FullNameProtocolMapper": "FullNameProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/groupMembershipProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/groupMembershipProtocolMapper:GroupMembershipProtocolMapper": "GroupMembershipProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/hardcodedClaimProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/hardcodedClaimProtocolMapper:HardcodedClaimProtocolMapper": "HardcodedClaimProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/hardcodedRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/hardcodedRoleProtocolMapper:HardcodedRoleProtocolMapper": "HardcodedRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/scriptProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/scriptProtocolMapper:ScriptProtocolMapper": "ScriptProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userAttributeProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userAttributeProtocolMapper:UserAttributeProtocolMapper": "UserAttributeProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userClientRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userClientRoleProtocolMapper:UserClientRoleProtocolMapper": "UserClientRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userPropertyProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userPropertyProtocolMapper:UserPropertyProtocolMapper": "UserPropertyProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userRealmRoleProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userRealmRoleProtocolMapper:UserRealmRoleProtocolMapper": "UserRealmRoleProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "openid/userSessionNoteProtocolMapper",
  "fqn": "pulumi_keycloak.openid",
  "classes": {
   "keycloak:openid/userSessionNoteProtocolMapper:UserSessionNoteProtocolMapper": "UserSessionNoteProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/client",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/client:Client": "Client"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/clientDefaultScope",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/clientDefaultScope:ClientDefaultScope": "ClientDefaultScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/clientScope",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/clientScope:ClientScope": "ClientScope"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/identityProvider",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/scriptProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/scriptProtocolMapper:ScriptProtocolMapper": "ScriptProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/userAttributeProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/userAttributeProtocolMapper:UserAttributeProtocolMapper": "UserAttributeProtocolMapper"
  }
 },
 {
  "pkg": "keycloak",
  "mod": "saml/userPropertyProtocolMapper",
  "fqn": "pulumi_keycloak.saml",
  "classes": {
   "keycloak:saml/userPropertyProtocolMapper:UserPropertyProtocolMapper": "UserPropertyProtocolMapper"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "keycloak",
  "token": "pulumi:providers:keycloak",
  "fqn": "pulumi_keycloak",
  "class": "Provider"
 }
]
"""
)
